=======
银行卡号验证库
=======


.. image:: https://img.shields.io/pypi/v/cardbin.svg
        :target: https://pypi.python.org/pypi/cardbin

.. image:: https://img.shields.io/travis/bopo/cardbin.svg
        :target: https://travis-ci.org/bopo/cardbin

.. image:: https://readthedocs.org/projects/cardbin/badge/?version=latest
        :target: https://cardbin.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/bopo/cardbin/shield.svg
     :target: https://pyup.io/repos/github/bopo/cardbin/
     :alt: Updates



* 开源协议: MIT license
* 在线文档: https://cardbin.readthedocs.io.


功能
--------

* 检查一个银行卡号是哪个银行，什么卡

Credits
---------


